/* Generated automatically by the program `genattrtab'
   from the machine description file `md'.  */

#define IN_TARGET_CODE 1
#include "config.h"
#include "system.h"
#include "coretypes.h"
#include "backend.h"
#include "predict.h"
#include "tree.h"
#include "rtl.h"
#include "alias.h"
#include "options.h"
#include "varasm.h"
#include "stor-layout.h"
#include "calls.h"
#include "insn-attr.h"
#include "memmodel.h"
#include "tm_p.h"
#include "insn-config.h"
#include "recog.h"
#include "regs.h"
#include "real.h"
#include "output.h"
#include "toplev.h"
#include "flags.h"
#include "emit-rtl.h"

#define operands recog_data.operand

int
internal_dfa_insn_code (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 112:  /* cstoredf4 */
    case 111:  /* cstoresf4 */
      extract_constrain_insn_cached (insn);
      if ((
#line 279 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 8;
        }
      else if ((
#line 352 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 21 /* 0x15 */;
        }
      else if ((
#line 419 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 33 /* 0x21 */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 145:  /* insv_32 */
    case 144:  /* extv_32 */
    case 103:  /* *lshrsi3_bshift */
    case 99:  /* lshrdi3_long */
    case 95:  /* *ashrsi3_bshift */
    case 91:  /* ashrdi3_long */
    case 82:  /* ashldi3_long */
    case 81:  /* ashlsi3_bshift */
      extract_constrain_insn_cached (insn);
      if ((
#line 269 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 6;
        }
      else if ((
#line 342 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 19 /* 0x13 */;
        }
      else if ((
#line 409 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 31 /* 0x1f */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 71:  /* *movsi_internal5_pltop */
    case 64:  /* *movdi_internal5_pltop */
      extract_constrain_insn_cached (insn);
      if ((
#line 249 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 2;
        }
      else if ((
#line 322 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 15 /* 0xf */;
        }
      else if ((
#line 389 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 27 /* 0x1b */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 69:  /* movsi_status */
    case 62:  /* movdi_status */
      extract_constrain_insn_cached (insn);
      if ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 1;
        }
      else if ((
#line 317 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 14 /* 0xe */;
        }
      else if ((
#line 384 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 26 /* 0x1a */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 146:  /* atomic_compare_and_swapsi */
    case 142:  /* set_text */
    case 141:  /* set_got */
    case 140:  /* trap */
    case 130:  /* blockage */
    case 106:  /* *lshrsi_reg */
    case 105:  /* *lshrsi_inline */
    case 104:  /* *lshrsi3_with_size_opt */
    case 101:  /* lshrdi3_reg */
    case 100:  /* lshrdi3_const */
    case 98:  /* *ashrsi_reg */
    case 97:  /* *ashrsi_inline */
    case 96:  /* *ashrsi3_with_size_opt */
    case 93:  /* ashrdi3_reg */
    case 90:  /* *ashlsi_reg */
    case 89:  /* *ashlsi_inline */
    case 88:  /* *ashlsi3_with_rotate */
    case 87:  /* *ashlsi3_with_size_opt */
    case 84:  /* ashldi3_reg */
    case 83:  /* ashldi3_const */
    case 61:  /* extendsidi2 */
    case 60:  /* extendsidi2_long */
      return 38 /* 0x26 */;

    case 34:  /* udivsi3 */
    case 33:  /* divsi3_internal */
      extract_constrain_insn_cached (insn);
      if ((
#line 264 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 5;
        }
      else if ((
#line 337 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 18 /* 0x12 */;
        }
      else if ((
#line 404 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 30 /* 0x1e */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 32:  /* *usmulsi3_highpart */
    case 31:  /* *umulsi3_highpart */
    case 30:  /* *smulsi3_highpart */
    case 26:  /* mulsi3 */
      extract_constrain_insn_cached (insn);
      if ((
#line 259 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 4;
        }
      else if ((
#line 332 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 17 /* 0x11 */;
        }
      else if ((
#line 399 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 29 /* 0x1d */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 9:  /* fix_truncsfsi2 */
      extract_constrain_insn_cached (insn);
      if ((
#line 299 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 12 /* 0xc */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 16:  /* fix_truncdfdi2 */
    case 15:  /* floatdidf2 */
    case 8:  /* floatsisf2 */
      extract_constrain_insn_cached (insn);
      if ((
#line 294 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 11 /* 0xb */;
        }
      else if ((
#line 367 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 24 /* 0x18 */;
        }
      else if ((
#line 434 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 36 /* 0x24 */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 14:  /* sqrtdf2 */
    case 7:  /* sqrtsf2 */
      extract_constrain_insn_cached (insn);
      if ((
#line 289 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 10 /* 0xa */;
        }
      else if ((
#line 362 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 23 /* 0x17 */;
        }
      else if ((
#line 429 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 35 /* 0x23 */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 13:  /* divdf3 */
    case 6:  /* divsf3 */
      extract_constrain_insn_cached (insn);
      if ((
#line 284 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 9;
        }
      else if ((
#line 357 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 22 /* 0x16 */;
        }
      else if ((
#line 424 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 34 /* 0x22 */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case 12:  /* muldf3 */
    case 11:  /* subdf3 */
    case 10:  /* adddf3 */
    case 5:  /* mulsf3 */
    case 4:  /* subsf3 */
    case 3:  /* addsf3 */
      extract_constrain_insn_cached (insn);
      if ((
#line 274 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 7;
        }
      else if ((
#line 347 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 20 /* 0x14 */;
        }
      else if ((
#line 414 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 32 /* 0x20 */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    case 51:  /* zero_extendhisi2 */
    case 52:  /* zero_extendqihi2 */
    case 53:  /* zero_extendqisi2 */
    case 65:  /* *movdi_internal2_bshift */
    case 66:  /* *movdi_internal2 */
    case 67:  /* *movdi_internal */
    case 72:  /* *movsi_internal2 */
    case 73:  /* *movhi_internal2 */
    case 74:  /* *movqi_internal2 */
    case 75:  /* movsi4_rev */
    case 76:  /* *movsf_internal */
    case 77:  /* *movdf_internal_64_bshift */
    case 78:  /* *movdf_internal_64 */
    case 79:  /* *movdf_internal */
      extract_constrain_insn_cached (insn);
      if ((((cached_type = get_attr_type (insn)) == TYPE_BRANCH) || (cached_type == TYPE_JUMP) || (cached_type == TYPE_CALL) || (cached_type == TYPE_ARITH) || (cached_type == TYPE_DARITH) || (cached_type == TYPE_ICMP) || (cached_type == TYPE_NOP) || (cached_type == TYPE_NO_DELAY_ARITH)) && ((
#line 239 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 0;
        }
      else if ((cached_type == TYPE_MOVE) && ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 1;
        }
      else if (((cached_type == TYPE_LOAD) || (cached_type == TYPE_NO_DELAY_LOAD)) && ((
#line 249 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 2;
        }
      else if (((cached_type == TYPE_STORE) || (cached_type == TYPE_NO_DELAY_STORE)) && ((
#line 254 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 3;
        }
      else if (((cached_type == TYPE_IMUL) || (cached_type == TYPE_NO_DELAY_IMUL)) && ((
#line 259 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 4;
        }
      else if ((cached_type == TYPE_IDIV) && ((
#line 264 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 5;
        }
      else if ((cached_type == TYPE_BSHIFT) && ((
#line 269 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 6;
        }
      else if (((cached_type == TYPE_FADD) || (cached_type == TYPE_FRSUB) || (cached_type == TYPE_FMUL)) && ((
#line 274 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 7;
        }
      else if ((cached_type == TYPE_FCMP) && ((
#line 279 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 8;
        }
      else if ((cached_type == TYPE_FDIV) && ((
#line 284 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 9;
        }
      else if ((cached_type == TYPE_FSQRT) && ((
#line 289 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 10 /* 0xa */;
        }
      else if ((cached_type == TYPE_FCVT) && ((
#line 294 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 11 /* 0xb */;
        }
      else if ((cached_type == TYPE_FINT) && ((
#line 299 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2)))
        {
	  return 12 /* 0xc */;
        }
      else if (((cached_type == TYPE_BRANCH) || (cached_type == TYPE_JUMP) || (cached_type == TYPE_CALL) || (cached_type == TYPE_ARITH) || (cached_type == TYPE_DARITH) || (cached_type == TYPE_ICMP) || (cached_type == TYPE_NOP) || (cached_type == TYPE_NO_DELAY_ARITH)) && ((
#line 312 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 13 /* 0xd */;
        }
      else if ((cached_type == TYPE_MOVE) && ((
#line 317 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 14 /* 0xe */;
        }
      else if (((cached_type == TYPE_LOAD) || (cached_type == TYPE_NO_DELAY_LOAD)) && ((
#line 322 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 15 /* 0xf */;
        }
      else if (((cached_type == TYPE_STORE) || (cached_type == TYPE_NO_DELAY_STORE)) && ((
#line 327 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 16 /* 0x10 */;
        }
      else if (((cached_type == TYPE_IMUL) || (cached_type == TYPE_NO_DELAY_IMUL)) && ((
#line 332 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 17 /* 0x11 */;
        }
      else if ((cached_type == TYPE_IDIV) && ((
#line 337 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 18 /* 0x12 */;
        }
      else if ((cached_type == TYPE_BSHIFT) && ((
#line 342 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 19 /* 0x13 */;
        }
      else if (((cached_type == TYPE_FADD) || (cached_type == TYPE_FRSUB) || (cached_type == TYPE_FMUL)) && ((
#line 347 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 20 /* 0x14 */;
        }
      else if ((cached_type == TYPE_FCMP) && ((
#line 352 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 21 /* 0x15 */;
        }
      else if ((cached_type == TYPE_FDIV) && ((
#line 357 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 22 /* 0x16 */;
        }
      else if ((cached_type == TYPE_FSQRT) && ((
#line 362 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 23 /* 0x17 */;
        }
      else if ((cached_type == TYPE_FCVT) && ((
#line 367 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1)))
        {
	  return 24 /* 0x18 */;
        }
      else if (((cached_type == TYPE_BRANCH) || (cached_type == TYPE_JUMP) || (cached_type == TYPE_CALL) || (cached_type == TYPE_ARITH) || (cached_type == TYPE_DARITH) || (cached_type == TYPE_ICMP) || (cached_type == TYPE_NOP) || (cached_type == TYPE_NO_DELAY_ARITH)) && ((
#line 379 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 25 /* 0x19 */;
        }
      else if ((cached_type == TYPE_MOVE) && ((
#line 384 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 26 /* 0x1a */;
        }
      else if (((cached_type == TYPE_LOAD) || (cached_type == TYPE_NO_DELAY_LOAD)) && ((
#line 389 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 27 /* 0x1b */;
        }
      else if (((cached_type == TYPE_STORE) || (cached_type == TYPE_NO_DELAY_STORE)) && ((
#line 394 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 28 /* 0x1c */;
        }
      else if (((cached_type == TYPE_IMUL) || (cached_type == TYPE_NO_DELAY_IMUL)) && ((
#line 399 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 29 /* 0x1d */;
        }
      else if ((cached_type == TYPE_IDIV) && ((
#line 404 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 30 /* 0x1e */;
        }
      else if ((cached_type == TYPE_BSHIFT) && ((
#line 409 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 31 /* 0x1f */;
        }
      else if (((cached_type == TYPE_FADD) || (cached_type == TYPE_FRSUB) || (cached_type == TYPE_FMUL)) && ((
#line 414 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 32 /* 0x20 */;
        }
      else if ((cached_type == TYPE_FCMP) && ((
#line 419 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 33 /* 0x21 */;
        }
      else if ((cached_type == TYPE_FDIV) && ((
#line 424 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 34 /* 0x22 */;
        }
      else if ((cached_type == TYPE_FSQRT) && ((
#line 429 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 35 /* 0x23 */;
        }
      else if ((cached_type == TYPE_FCVT) && ((
#line 434 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0)))
        {
	  return 36 /* 0x24 */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    default:
      extract_constrain_insn_cached (insn);
      if ((
#line 239 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (2))
        {
	  return 0;
        }
      else if ((
#line 312 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (1))
        {
	  return 13 /* 0xd */;
        }
      else if ((
#line 379 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/microblaze/microblaze.md"
(microblaze_pipe)) == (0))
        {
	  return 25 /* 0x19 */;
        }
      else
        {
	  return 38 /* 0x26 */;
        }

    }
}

