/* Generated automatically by the program `genenums'
   from the machine description file.  */

#include "config.h"

#include "system.h"

#include "insn-constants.h"


const char *const unspec_strings[] = {
  "UNSPEC_IPREFETCH"
};
